@@ -183,8 +183,7 @@ impl Iterator for Lexer<'_> {
 }
 
 pub(crate) fn lex(input: &str) -> Vec<(SyntaxKind, String)> {
-    let mut lexer = Lexer::new(input);
-    lexer.by_ref().collect::<Vec<_>>()
+    Lexer::new(input).collect()
 }
 
 #[cfg(test)]
